@@ -7,7 +7,7 @@ from plateypus.setup.createTubeLayout import TubeLayoutPage
 from plateypus.setup.createPlateLayout import BlankSelectionPage
 
 experimentParameters = {}
-parametersUpdatedByGridGUI = {}
+dataTypeDict = {'Cytokine':'cyt','Bulk/Single cell':'cell','Killing':'killing'}
 
 class ExperimentSetupStartPage(tk.Frame):
     def __init__(self, master,fName,bPage):
@@ -28,26 +28,30 @@ class ExperimentSetupStartPage(tk.Frame):
         rb2a.grid(row=0,column=0,sticky=tk.W)
         rb2b.grid(row=1,column=0,sticky=tk.W)
         
-        v3 = tk.StringVar(value='both')
-        l3 = tk.Label(mainWindow, text="for:     ")
-        l3.grid(row=0,column=1,rowspan=2,sticky=tk.EW)
-        rb3a = tk.Radiobutton(mainWindow, text="Cells",padx = 20, variable=v3, value='cell')
-        rb3b = tk.Radiobutton(mainWindow,text="Cytokines",padx = 20, variable=v3, value='cyt')
-        rb3c = tk.Radiobutton(mainWindow,text="Cells and Cytokines",padx = 20, variable=v3, value='both')
-        rb3a.grid(row=0,column=2,sticky=tk.W)
-        rb3b.grid(row=1,column=2,sticky=tk.W)
-        rb3c.grid(row=2,column=2,sticky=tk.W)
+        #v3 = tk.StringVar(value='both')
+        #l3 = tk.Label(mainWindow, text="for:     ")
+        #l3.grid(row=0,column=1,rowspan=2,sticky=tk.EW)
+        #rb3a = tk.Radiobutton(mainWindow, text="Cells",padx = 20, variable=v3, value='cell')
+        #rb3b = tk.Radiobutton(mainWindow,text="Cytokines",padx = 20, variable=v3, value='cyt')
+        #rb3c = tk.Radiobutton(mainWindow,text="Cells and Cytokines",padx = 20, variable=v3, value='both')
+        #rb3a.grid(row=0,column=2,sticky=tk.W)
+        #rb3b.grid(row=1,column=2,sticky=tk.W)
+        #rb3c.grid(row=2,column=2,sticky=tk.W)
+        
+        labelList,cbList,cbVarList = [],[],[]
+        for i,dataT in enumerate(list(dataTypeDict.keys())):
+            l = tk.Label(mainWindow,text=dataT).grid(row=i,column=3,sticky=tk.W)
+            v = tk.BooleanVar(value=False)
+            cb = tk.Checkbutton(mainWindow, variable=v)
+            cb.grid(row=i,column=1,sticky=tk.W)
+            cbList.append(cb)
+            cbVarList.append(v)
         
         def experimentLayout():
-            if v3.get() == 'both':
-                if 'experimentParameters-'+folderName+'-cyt.json' in os.listdir('misc'):
-                    experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-cyt.json','r'))
-                elif 'experimentParameters-'+folderName+'-cell.json' in os.listdir('misc'):
-                    experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-cell.json','r'))
-                else:
-                    experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'.json','r'))
-            else:
-                experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-'+v3.get()+'.json','r'))
+            for dataType in dataTypeList:
+                if 'experimentParameters-'+folderName+'-'+dataType+'.json' in os.listdir('misc'):
+                    experimentParameters = json.load(open('misc/experimentParameters-'+folderName+'-'+dataType+'.json','r'))
+                    break
             if 'format' not in experimentParameters.keys():
                 experimentParameters['format'] = 'plate'
             if experimentParameters['format'] == 'plate':
@@ -60,7 +64,10 @@ class ExperimentSetupStartPage(tk.Frame):
                     levelValues.append(experimentParameters['levelLabelDict'][level])
                 maxNumLevelValues = len(max(levelValues,key=len))
                 levels = list(experimentParameters['levelLabelDict'].keys())
-                master.switch_frame(BlankSelectionPage,folderName,levels,levelValues,maxNumLevelValues,experimentParameters['numPlates'],plateDimensions,v3.get(),ExperimentSetupStartPage,bPage)
+                if 'killing' in dataTypeList:
+                    levels = levels[:-1]
+                    levelValues = levelValues[:-1]
+                master.switch_frame(BlankSelectionPage,folderName,levels,levelValues,maxNumLevelValues,experimentParameters['numPlates'],plateDimensions,dataTypeList,ExperimentSetupStartPage,bPage)
             #Tube mode
             else:
                 fcsFiles = []
@@ -83,8 +90,8 @@ class ExperimentSetupStartPage(tk.Frame):
                 master.switch_frame(TubeLayoutPage,folderName,experimentParameters['levelLabelDict'],len(fcsFiles),v3.get(),ExperimentSetupStartPage,bPage)
         
         def collectInput():
-            global dataType
-            dataType = v3.get()
+            global dataTypeList
+            dataTypeList = [list(dataTypeDict.values())[i] for i,x in enumerate(cbVarList) if x.get()]
             if v2.get() == 'inpt':
                 master.switch_frame(ExperimentFormatPage,folderName)
             elif v2.get() == 'pl':
@@ -216,13 +223,16 @@ class PlateExperimentParameterPage(tk.Frame):
          
         def collectInputs():
             experimentParameters['numPlates'] = int(e0.get())
-            experimentParameters['numAllLevels'] = int(e2.get())+1
+            
+            #Incucyte datasets have time encoded in them already
+            if 'killing' in dataTypeList:
+                experimentParameters['numAllLevels'] = int(e2.get())
+            else:
+                experimentParameters['numAllLevels'] = int(e2.get())+1
             if v3.get() == 384:
                 experimentParameters['overallPlateDimensions'] = [16,24]
-                parametersUpdatedByGridGUI['currentPlateDimensions'] = [16,24]
             else:
                 experimentParameters['overallPlateDimensions'] = [8,12]
-                parametersUpdatedByGridGUI['currentPlateDimensions'] = [8,12]
             
             if plateMultiplexVar.get() and barcodeMultiplexVar.get():
                 multiplexingOption = '96->384 well + Barcoding'
@@ -290,7 +300,6 @@ class BarcodingPage(tk.Frame):
             plateStart = combinedPlateNum*totalPlatesPerBarcodedPlate+1
             plateEnd = (combinedPlateNum+1)*totalPlatesPerBarcodedPlate
             allPlateIndices = list(range(plateStart,plateEnd+2,plateSkip))
-            print(allPlateIndices)
             combinedEntry.grid(row=combinedPlateNum*numberOfBarcodedPlates+1,column=0)
             plateBarcodingVarList,plateEntryList = [],[]
             for plateNum in range(numberOfBarcodedPlates):
@@ -439,7 +448,7 @@ class allLevelNamePage(tk.Frame):
             l1 = tk.Label(mainWindow, text="Condition "+str(conditionLevelNumber))
             e1 = tk.Entry(mainWindow)
             v = tk.IntVar()
-            if conditionLevelNumber == 1:
+            if conditionLevelNumber == 1 and 'killing' not in dataTypeList:
                 #e1 = tk.Entry(mainWindow,state='readonly')
                 e1.insert(tk.END, 'Time')
                 e2 = tk.Entry(mainWindow)
@@ -477,30 +486,28 @@ class allLevelNamePage(tk.Frame):
             numConditionLevelValues = []
             tiledLevels = []
             experimentParameters['columnVariableName'] = 'Time' 
-            timebool=False
             numericlevels = []
             for allLevelNumber in range(numAllLevels):
                 #Remove column variable from condition name list
                 if entryList1[allLevelNumber].get() == 'Time':
-                    timebool=True
-                    experimentParameters['numColumnLevelValues'] = int(entryList2[allLevelNumber].get())
                     experimentParameters['numColumnLevelValues'] = int(entryList2[allLevelNumber].get())
                 else:
                     conditionNames.append(str(entryList1[allLevelNumber].get()))
                     numConditionLevelValues.append(int(entryList2[allLevelNumber].get()))
                 numericlevels.append(numericCheckBoxVars[allLevelNumber].get() == 1)
+            if 'killing' in dataTypeList:
+                experimentParameters['numColumnLevelValues'] = 0 
+                experimentParameters['numConditionLevels'] = numAllLevels
+            else:
+                experimentParameters['numConditionLevels'] = numAllLevels - 1
 
-            experimentParameters['numConditionLevels'] = numAllLevels - 1
             experimentParameters['conditionLevelNames'] = conditionNames
             experimentParameters['allLevelNames'] = [experimentParameters['columnVariableName']]+conditionNames
             experimentParameters['numConditionLevelValues'] = numConditionLevelValues
             experimentParameters['numericLevels'] = numericlevels
-            parametersUpdatedByGridGUI['numLevelsUnparsed'] = numAllLevels
             experimentParameters[''] = tiledLevels
-            with open('misc/gui-parametersUpdatedByGridGUI.pkl','wb') as f:
-                pickle.dump(parametersUpdatedByGridGUI,f)
             master.switch_frame(columnLevelValuesPage,folderName)
-        
+
         def backCommand():
             if experimentParameters['format'] == 'tube':
                 master.switch_frame(TubeExperimentParameterPage,folderName)
@@ -630,31 +637,30 @@ class conditionLevelValuesPage(tk.Frame):
                 if keyToKeep in list(experimentParameters.keys()):
                     shortenedExperimentParameters[keyToKeep] = experimentParameters[keyToKeep]
             shortenedExperimentParameters['levelLabelDict'] = experimentParameters['allLevelValues']
-            if dataType == 'both':
-                with open('misc/experimentParameters-'+folderName+'-cell.json', 'w') as fp:
-                    json.dump(shortenedExperimentParameters, fp)
-                with open('misc/experimentParameters-'+folderName+'-cyt.json', 'w') as fp:
-                    json.dump(shortenedExperimentParameters, fp)
-            else:
+            for dataType in dataTypeList:
                 with open('misc/experimentParameters-'+folderName+'-'+dataType+'.json', 'w') as fp:
                     json.dump(shortenedExperimentParameters, fp)
             #{"A1-12": {"A1-4": ["Barcode 1-", "Barcode 2-"], "A5-8": ["Barcode 1+", "Barcode 2-"], "A9-12": ["Barcode 1-", "Barcode 2+"]}}
             #{"A1-4": ["A1", "A2", "A4", "A3"], "A5-8": ["A5", "A6", "A8", "A7"], "A9-12": ["A9", "A10", "A12", "A11"]}
-            if (dataType == 'both' or dataType == 'cell') and experimentParameters['format'] == 'plate':
+            if 'cell' in dataTypeList and experimentParameters['format'] == 'plate':
                 #Both
                 if '+' in globalMultiplexingVar:
                     for plate in experimentParameters['barcodingDict']:
-                        subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
+                        if plate not in os.listdir('inputData/singleCellCSVFiles/'):
+                            subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
                 else:
                     if 'Barcoding' in globalMultiplexingVar:
                         for plate in experimentParameters['barcodingDict']:
-                            subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
+                            if plate not in os.listdir('inputData/singleCellCSVFiles/'):
+                                subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
                     elif '96' in globalMultiplexingVar:
                         for plate in experimentParameters['unpackingDict']:
-                            subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
+                            if plate not in os.listdir('inputData/singleCellCSVFiles/'):
+                                subprocess.run(['mkdir','inputData/singleCellCSVFiles/'+plate])
                     else:
                         for plateNum in range(1,experimentParameters['numPlates']+1):
-                            subprocess.run(['mkdir','inputData/singleCellCSVFiles/A'+str(plateNum)])
+                            if 'A'+str(plateNum) not in os.listdir('inputData/singleCellCSVFiles/'):
+                                subprocess.run(['mkdir','inputData/singleCellCSVFiles/A'+str(plateNum)])
             master.switch_frame(ExperimentSetupStartPage,folderName,backPage)
 
         buttonWindow = tk.Frame(self)
